@@ -534,7 +534,7 @@ def valid_dir(d):
     if not path.isdir(dir):
         return False
 
-    if set(['Makefile', 'make.bat']) & set(os.listdir(dir)):
+    if set(['Makefile', 'make.bat']) & set(os.listdir(dir)):  # type: ignore
         return False
 
     if d['sep']:
@@ -550,7 +550,7 @@ def valid_dir(d):
         d['dot'] + 'templates',
         d['master'] + d['suffix'],
     ]
-    if set(reserved_names) & set(os.listdir(dir)):
+    if set(reserved_names) & set(os.listdir(dir)):  # type: ignore
         return False
 
     return True
